@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: binary-tagged
 version: 0.1.3.1
-id: binary-tagged-0.1.3.1-fe2a180b67aea32197c73b98ed3f4d58
-key: binar_6I64QOaUElr616iey1mYCU
+id: binary-tagged-0.1.3.1-101f042861e5610dd2e62eedde2de570
+key: binar_59BLVaKqSRFJDVS80kW31l
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/binary-tagged#readme
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/binary-tagged-0.1.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/binary-tagged-0.1.3.1
-hs-libraries: HSbinary-tagged-0.1.3.1-6I64QOaUElr616iey1mYCU
+hs-libraries: HSbinary-tagged-0.1.3.1-59BLVaKqSRFJDVS80kW31l
 depends:
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
